@@ -6,10 +6,10 @@ from aiohttp_sqlalchemy.exceptions import DuplicateRequestKeyError
 
 if TYPE_CHECKING:
     from aiohttp.web import Request, StreamResponse
-    from typing import Callable
+    from typing import Awaitable, Callable
 
 
-def sa_middleware(key: str = DEFAULT_KEY) -> 'Callable':
+def sa_middleware(key: str = DEFAULT_KEY) -> 'Callable[..., Awaitable[StreamResponse]]':
     """ SQLAlchemy asynchronous middleware factory. """
     @middleware
     async def sa_middleware_(request: 'Request', handler: 'Callable')\
@@ -17,8 +17,8 @@ def sa_middleware(key: str = DEFAULT_KEY) -> 'Callable':
         if key in request:
             raise DuplicateRequestKeyError(key)
 
-        Session = request.config_dict.get(key)
-        async with Session() as request[key]:
+        session_factory = request.config_dict.get(key)
+        async with session_factory() as request[key]:
             return await handler(request)
 
     return sa_middleware_
